@@ -188,10 +188,24 @@
 # define NM_AVAILABLE_IN_1_16
 #endif
 
-#if NM_VERSION_MAX_ALLOWED < NM_VERSION_1_16_4
-# define NM_AVAILABLE_IN_1_16_4          G_UNAVAILABLE(1,16.4)
+#if NM_VERSION_MIN_REQUIRED >= NM_VERSION_1_18
+# define NM_DEPRECATED_IN_1_18           G_DEPRECATED
+# define NM_DEPRECATED_IN_1_18_FOR(f)    G_DEPRECATED_FOR(f)
 #else
-# define NM_AVAILABLE_IN_1_16_4
+# define NM_DEPRECATED_IN_1_18
+# define NM_DEPRECATED_IN_1_18_FOR(f)
+#endif
+
+#if NM_VERSION_MAX_ALLOWED < NM_VERSION_1_18
+# define NM_AVAILABLE_IN_1_18            G_UNAVAILABLE(1,18)
+#else
+# define NM_AVAILABLE_IN_1_18
+#endif
+
+#if NM_VERSION_MAX_ALLOWED < NM_VERSION_1_18_2
+# define NM_AVAILABLE_IN_1_18_2          G_UNAVAILABLE(1,18.2)
+#else
+# define NM_AVAILABLE_IN_1_18_2
 #endif
 
 #endif  /* NM_VERSION_H */
