@@ -40,7 +40,7 @@
 #include "nm-dbus-helpers.h"
 #include "nm-device-tun.h"
 #include "nm-setting-connection.h"
-#include "shared/nm-utils/nm-udev-utils.h"
+#include "nm-udev-aux/nm-udev-utils.h"
 
 #include "introspection/org.freedesktop.NetworkManager.Device.h"
 
@@ -1841,14 +1841,15 @@ nm_device_disambiguate_names (NMDevice **devices,
 	for (i = 0; i < num_devices; i++) {
 		if (duplicates[i] && NM_IS_DEVICE_BT (devices[i])) {
 			const char *devname = nm_device_bt_get_name (NM_DEVICE_BT (devices[i]));
+			char *name;
 
 			if (!devname)
 				continue;
 
 			g_free (names[i]);
-			names[i] = g_strdup_printf ("%s (%s)",
-			                            get_device_type_name_with_iface (devices[i]),
-			                            devname);
+			name = get_device_type_name_with_iface (devices[i]);
+			names[i] = g_strdup_printf ("%s (%s)", name, devname);
+			g_free (name);
 		}
 	}
 	if (!find_duplicates (names, duplicates, num_devices))
