@@ -25,7 +25,7 @@
 
 #include "nm-utils.h"
 #include "nm-checkpoint.h"
-#include "nm-common-macros.h"
+#include "nm-libnm-core-intern/nm-common-macros.h"
 #include "nm-device-ethernet.h"
 #include "nm-device-wifi.h"
 #include "nm-core-internal.h"
