@@ -163,11 +163,14 @@ void                nm_manager_add_and_activate_connection_async  (NMManager *ma
                                                                    NMConnection *partial,
                                                                    NMDevice *device,
                                                                    const char *specific_object,
+                                                                   GVariant *options,
+                                                                   gboolean force_v2,
                                                                    GCancellable *cancellable,
                                                                    GAsyncReadyCallback callback,
                                                                    gpointer user_data);
 NMActiveConnection *nm_manager_add_and_activate_connection_finish (NMManager *manager,
                                                                    GAsyncResult *result,
+                                                                   GVariant **out_result,
                                                                    GError **error);
 
 gboolean nm_manager_deactivate_connection        (NMManager *manager,
@@ -184,31 +187,54 @@ gboolean nm_manager_deactivate_connection_finish (NMManager *manager,
                                                   GError **error);
 
 const GPtrArray *nm_manager_get_checkpoints (NMManager *manager);
-void nm_manager_checkpoint_create_async (NMManager *manager,
-                                         const GPtrArray *devices,
-                                         guint32 rollback_timeout,
-                                         NMCheckpointCreateFlags flags,
-                                         GCancellable *cancellable,
-                                         GAsyncReadyCallback callback,
-                                         gpointer user_data);
+void nm_manager_checkpoint_create (NMManager *manager,
+                                   const GPtrArray *devices,
+                                   guint32 rollback_timeout,
+                                   NMCheckpointCreateFlags flags,
+                                   GCancellable *cancellable,
+                                   GAsyncReadyCallback callback,
+                                   gpointer user_data);
 NMCheckpoint *nm_manager_checkpoint_create_finish (NMManager *manager,
                                                    GAsyncResult *result,
                                                    GError **error);
-void nm_manager_checkpoint_destroy_async (NMManager *manager,
-                                          NMCheckpoint *checkpoint,
-                                          GCancellable *cancellable,
-                                          GAsyncReadyCallback callback,
-                                          gpointer user_data);
+void nm_manager_checkpoint_destroy (NMManager *manager,
+                                    const char *checkpoint_path,
+                                    GCancellable *cancellable,
+                                    GAsyncReadyCallback callback,
+                                    gpointer user_data);
 gboolean nm_manager_checkpoint_destroy_finish (NMManager *manager,
                                                GAsyncResult *result,
                                                GError **error);
-void nm_manager_checkpoint_rollback_async (NMManager *manager,
-                                           NMCheckpoint *checkpoint,
-                                           GCancellable *cancellable,
-                                           GAsyncReadyCallback callback,
-                                           gpointer user_data);
+void nm_manager_checkpoint_rollback (NMManager *manager,
+                                     const char *checkpoint_path,
+                                     GCancellable *cancellable,
+                                     GAsyncReadyCallback callback,
+                                     gpointer user_data);
 GHashTable *nm_manager_checkpoint_rollback_finish (NMManager *manager,
                                                    GAsyncResult *result,
                                                    GError **error);
+void nm_manager_checkpoint_adjust_rollback_timeout (NMManager *manager,
+                                                    const char *checkpoint_path,
+                                                    guint32 add_timeout,
+                                                    GCancellable *cancellable,
+                                                    GAsyncReadyCallback callback,
+                                                    gpointer user_data);
+gboolean nm_manager_checkpoint_adjust_rollback_timeout_finish (NMManager *manager,
+                                                               GAsyncResult *result,
+                                                               GError **error);
+
+/*****************************************************************************/
+
+typedef struct {
+	NMActiveConnection *active;
+	GVariant *add_and_activate_output;
+} _NMActivateResult;
+
+_NMActivateResult *_nm_activate_result_new (NMActiveConnection *active,
+                                            GVariant *add_and_activate_output);
+
+void _nm_activate_result_free (_NMActivateResult *result);
+
+/*****************************************************************************/
 
 #endif /* __NM_MANAGER_H__ */
