@@ -21,14 +21,12 @@
 
 #include "nm-default.h"
 
-#include <string.h>
+#include "nm-remote-connection.h"
 
 #include "nm-dbus-interface.h"
 #include "nm-utils.h"
 #include "nm-setting-connection.h"
 #include "nm-core-internal.h"
-
-#include "nm-remote-connection.h"
 #include "nm-remote-connection-private.h"
 #include "nm-object-private.h"
 #include "nm-dbus-helpers.h"
@@ -918,7 +916,7 @@ get_property (GObject *object, guint prop_id,
 		g_value_set_boolean (value, NM_REMOTE_CONNECTION_GET_PRIVATE (object)->unsaved);
 		break;
 	case PROP_FLAGS:
-		g_value_set_boolean (value, NM_REMOTE_CONNECTION_GET_PRIVATE (object)->flags);
+		g_value_set_uint (value, NM_REMOTE_CONNECTION_GET_PRIVATE (object)->flags);
 		break;
 	case PROP_FILENAME:
 		g_value_set_string (value, NM_REMOTE_CONNECTION_GET_PRIVATE (object)->filename);
