@@ -24,9 +24,9 @@
 
 #include <net/ethernet.h>
 
+#include "nm-std-aux/unaligned.h"
 #include "platform/nm-platform.h"
-#include "nm-utils/unaligned.h"
-#include "nm-utils/nm-c-list.h"
+#include "nm-glib-aux/nm-c-list.h"
 #include "nm-utils.h"
 
 #include "systemd/nm-sd.h"
